@@ -16,6 +16,8 @@ You should have received a copy of the GNU Affero General Public License
 along with this program.  If not, see <https://www.gnu.org/licenses/>.
 """
 
+from typing import List, Union
+
 from .http import HttpClient
 from .models import CATEGORIES, Result
 
@@ -26,7 +28,7 @@ class Client:
     def __init__(self):
         self.http = HttpClient()
 
-    async def get_image(self, category: str, amount: int = 1) -> Result:
+    async def get_image(self, category: str, amount: int = 1) -> Union[Result, List[Result]]:
         """
         |coro|
 
@@ -41,12 +43,14 @@ class Client:
 
         Returns
         -------
-        nekosbest.Result
+        Union[nekosbest.Result, List[nekosbest.Result]]
         """
         if not category in CATEGORIES:
-            raise ValueError("This isn't a valid category.")
+            raise ValueError(
+                f"This isn't a valid category. It must be one of the following: {', '.join(CATEGORIES)}."
+            )
         if not 1 <= amount <= 20:
             raise ValueError("Amount parameter must be between 1 and 20.")
 
-        result = await self.http.get(category, amount)
-        return Result(result)
+        data = await self.http.get(category, amount)
+        return Result(data) if amount == 1 else [Result(r) for r in data]
