@@ -20,21 +20,34 @@ from typing import Optional
 
 CATEGORIES = (
     "baka",
+    "bite",
+    "blush",
+    "bored",
     "cry",
     "cuddle",
     "dance",
+    "facepalm",
     "feed",
+    "happy",
+    "highfive",
     "hug",
     "kiss",
     "laugh",
     "nekos",
     "pat",
     "poke",
+    "pout",
+    "shrug",
     "slap",
+    "sleep",
     "smile",
     "smug",
+    "stare",
+    "think",
+    "thumbsup",
     "tickle",
     "wave",
+    "wink",
 )
 
 
